---
slug: /configuration-management-introduction
---

# Introduction to configuration management

seekdb manages configurations by setting configuration items and system variables.

## Configuration items

Configuration items are primarily used for O&M and are commonly used to control the behavior of machines and higher-level systems. They can be used as startup parameters and can be modified at runtime to adjust system behavior.

## System variables

System variables are typically bound to user sessions and are used to control SQL behavior at the session level.

Both global and session-level variables are supported. When a global system variable is set, it does not take effect in the current session. However, any new session will read the updated variable value. When a session-level system variable is set, it only takes effect in the current session.

## Comparison between system configuration items and system variables

| Feature | System Configuration Item | System Variable |
|--------|----------|----------|
| Scope of effect | Instance | Global or session level |
| Effective method | <ul><li>Dynamic effective: when `edit_level` is `dynamic_effective`. </li><li>Effective after restart: when `edit_level` is `static_effective`. </li></ul> | <ul><li>Session-level variables only take effect in the current session and are ineffective in other sessions. </li><li>Global-level variables are ineffective in the current session and will only take effect after a new session is established upon re-login. </li></ul> |
| Modification method | <ul><li>Supports modification through SQL statements. Example: <br/> `Alter SYSTEM SET schema_history_expire_time='1h';` </li><li>Supports modification through startup parameters. Example: <br/> `/usr/bin/observer --base-dir /var/lib/oceanbase-lite --schema_history_expire_time='1h'`   </li></ul> | Only supports modification through SQL statements. Example: <br/> `SET ob_query_timeout = 20000000;`<br/> `SET GLOBAL ob_query_timeout = 20000000;`   |
| Lifecycle | Long, from process startup to exit. | Short, effective only after the schema is successfully created. |
| Query method | You can use the `SHOW PARAMETERS` statement to query. Example: <br/>` SHOW PARAMETERS LIKE 'schema_history_expire_time';` | You can use the `SHOW [GLOBAL] VARIABLES` or `SELECT` statement to query. Examples: `SHOW VARIABLES LIKE 'ob_query_timeout';`<br/> `SHOW GLOBAL VARIABLES LIKE 'ob_query_timeout';` <br/>`SELECT * FROM INFORMATION_SCHEMA.SESSION_VARIABLES WHERE VARIABLE_NAME = 'ob_query_timeout';`<br/>`SELECT * FROM INFORMATION_SCHEMA.GLOBAL_VARIABLES WHERE VARIABLE_NAME = 'ob_query_timeout';` |